"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.QueryBuilder = void 0;
// Opciones para el QUERY
// Clause Where
// Crea los querys
let QueryBuilder = exports.QueryBuilder = void 0;
(function (_QueryBuilder) {
  function query(tableName, options) {
    let sqlParts = ['SELECT', options.columns ?? "*", 'FROM', tableName];
    if (options.where) {
      sqlParts.push("WHERE");
      sqlParts.push(options.where.clause);
    }
    if (options.order) {
      sqlParts.push("ORDER BY");
      sqlParts.push(options.order);
    }
    if (options.limit) {
      sqlParts.push("LIMIT");
      sqlParts.push(options.limit);
      if (options.page) {
        sqlParts.push("OFFSET");
        sqlParts.push(options.limit * (options.page - 1));
      }
    }
    return sqlParts.filter(p => p !== '').join(' ');
  }
  _QueryBuilder.query = query;
  function create(tableName, object) {
    const keys = Object.keys(object);
    const columns = keys.join(', ');
    const values = keys.map(() => '?').join(', ');
    return `INSERT INTO ${tableName} (${columns}) VALUES (${values});`;
  }
  _QueryBuilder.create = create;
  function createArray(tableName, array) {
    if (array.length === 0) {
      throw new Error('array is empty');
    }
    const keys = Object.keys(array[0]);
    const columns = keys.join(', ');

    //const values = objects.map(() => `(${keys.map(() => '?').join(', ')})`).join(', ');
    const values = array.map(() => {
      const placeholders = keys.map(() => '?').join(', ');
      return `(${placeholders})`;
    }).join(', ');
    return `INSERT INTO ${tableName} (${columns}) VALUES ${values};`;
  }
  _QueryBuilder.createArray = createArray;
  function update(tableName, object, whereClause) {
    // Extrae el valor de "id" y crea un nuevo objeto sin ese dato
    //const { id, ...props } = object
    const values = Object.keys(object).map(k => `${k} = ?`).join(', ');
    return `UPDATE ${tableName} SET ${values} WHERE ${whereClause};`;
  }
  _QueryBuilder.update = update;
  function destroy(tableName, whereClause) {
    return `DELETE FROM ${tableName} WHERE ${whereClause};`;
  }
  _QueryBuilder.destroy = destroy;
  function destroyAll(tableName) {
    return `DELETE FROM ${tableName};`;
  }
  _QueryBuilder.destroyAll = destroyAll;
  function whereClausePlaceholders(array) {
    var args = [];
    for (let i = 0; i < array.length; i++) {
      args.push("?");
    }
    return "(" + args.join(", ") + ")";
  }
  _QueryBuilder.whereClausePlaceholders = whereClausePlaceholders;
  function escapeSqlString(sqlString) {
    let escape = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '\'';
    var sb = [];
    sb.push(escape);
    if (sqlString.indexOf(escape) != -1) {
      var length = sqlString.length;
      for (var i = 0; i < length; i++) {
        var c = sqlString.charAt(i);
        if (c == escape) {
          sb.push(escape);
        }
        sb.push(c);
      }
    } else {
      sb.push(sqlString);
    }
    sb.push(escape);
    return sb.join("");
  }
  _QueryBuilder.escapeSqlString = escapeSqlString;
})(QueryBuilder || (exports.QueryBuilder = QueryBuilder = {}));
var _default = exports.default = QueryBuilder;
//# sourceMappingURL=QueryBuilder.js.map